==> haskell-polysemy-1.7.1.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polysemy
version:              1.7.1.0
visibility:           public
id:                   polysemy-1.7.1.0-6y7Gw8alu22G0n0NI5GF7c
key:                  polysemy-1.7.1.0-6y7Gw8alu22G0n0NI5GF7c
license:              BSD-3-Clause
copyright:            2019-2021 Sandy Maguire
maintainer:           sandy@sandymaguire.me
author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/polysemy-research/polysemy#readme>

category:             Language
abi:                  59aa21f410977fa2ccf6583655e6e61f
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Forklift Polysemy.Internal.Index
    Polysemy.Internal.Kind Polysemy.Internal.NonDet
    Polysemy.Internal.Sing Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Law Polysemy.Membership
    Polysemy.NonDet Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.State Polysemy.State.Law Polysemy.Tagged Polysemy.Trace
    Polysemy.View Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-9.0.2/site-local/polysemy-1.7.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/polysemy-1.7.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polysemy
hs-libraries:         HSpolysemy-1.7.1.0-6y7Gw8alu22G0n0NI5GF7c
depends:
    QuickCheck-2.14.2-JoFwhdHSVnjCwZaPGQEEzD
    async-2.2.4-9EoKZTgytm43s60GeTAIZR base-4.15.1.0 containers-0.6.4.1
    first-class-families-0.8.0.1-baUR2cqZ6a8mZ6NW1ztpX mtl-2.2.2
    stm-2.5.0.0 syb-0.7.2.2-JvKYfJw95RM7Y4GXhTvfdV
    template-haskell-2.17.0.0
    th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp transformers-0.5.6.2
    type-errors-0.2.0.0-OoGE7DMBVJDZvFXUsKAfs
    unagi-chan-0.4.1.4-GkonEKA0PO5CMWmu54JVE

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-polysemy-1.9.1.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-polysemy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 polysemy
version:              1.9.1.1
visibility:           public
id:                   polysemy-1.9.1.1-KVN1Z5FdkfQ2Q6SvHCU7Nq
key:                  polysemy-1.9.1.1-KVN1Z5FdkfQ2Q6SvHCU7Nq
license:              BSD-3-Clause
copyright:            2019-2023 The Polysemy Lounge
maintainer:
    https://funprog.zulipchat.com/#narrow/stream/216942-Polysemy

author:               Sandy Maguire
homepage:             https://github.com/polysemy-research/polysemy#readme
synopsis:             Higher-order, low-boilerplate free monads.
description:
    Please see the README on GitHub at <https://github.com/polysemy-research/polysemy#readme>

category:             Language
abi:                  8f8b251972f37844b591f8e024618238
exposed:              True
exposed-modules:
    Polysemy Polysemy.Async Polysemy.AtomicState Polysemy.Bundle
    Polysemy.Embed Polysemy.Embed.Type Polysemy.Error Polysemy.Fail
    Polysemy.Fail.Type Polysemy.Final Polysemy.Fixpoint Polysemy.IO
    Polysemy.Input Polysemy.Internal Polysemy.Internal.Bundle
    Polysemy.Internal.Combinators Polysemy.Internal.CustomErrors
    Polysemy.Internal.CustomErrors.Redefined Polysemy.Internal.Fixpoint
    Polysemy.Internal.Index Polysemy.Internal.Kind
    Polysemy.Internal.NonDet Polysemy.Internal.Scoped
    Polysemy.Internal.Sing Polysemy.Internal.Strategy
    Polysemy.Internal.TH.Common Polysemy.Internal.TH.Effect
    Polysemy.Internal.Tactics Polysemy.Internal.Union
    Polysemy.Internal.Writer Polysemy.Membership Polysemy.NonDet
    Polysemy.Opaque Polysemy.Output Polysemy.Reader Polysemy.Resource
    Polysemy.Scoped Polysemy.State Polysemy.Tagged Polysemy.Trace
    Polysemy.Writer

hidden-modules:       Polysemy.Internal.PluginLookup Paths_polysemy
import-dirs:          /usr/lib/ghc-9.0.2/site-local/polysemy-1.9.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/polysemy-1.9.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-polysemy
hs-libraries:         HSpolysemy-1.9.1.1-KVN1Z5FdkfQ2Q6SvHCU7Nq
depends:
    async-2.2.4-FN1EWRVHp3S4oHdBJm7ot4 base-4.15.1.0 containers-0.6.4.1
    first-class-families-0.8.0.1-baUR2cqZ6a8mZ6NW1ztpX mtl-2.2.2
    stm-2.5.0.0 syb-0.7.2.3-ItYotKJTU3VJfC5cskyLmn
    template-haskell-2.17.0.0
    th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp transformers-0.5.6.2
    type-errors-0.2.0.2-LLcijlVvEglEd4H9jMG5CV
    unagi-chan-0.4.1.4-AdgovIHtPVCHGWIRwbcr1w

haddock-interfaces:   /usr/share/doc/haskell-polysemy/html/polysemy.haddock
haddock-html:         /usr/share/doc/haskell-polysemy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
